#!/usr/bin/perl
use lib '/home/erealms/ethereal/mgmt/perl';

#################################################################################
# Created       : Martin Foster
# Modified      : 02-Sep-2004
#################################################################################
#
# Reverse - Reverse-index generation for all works as to help in queried searches
# Copyright (C) 2000-2007  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 4-3526 Wolfe Cres
#                 Halifax, Nova Scotia
#                 B3L 3S2
#
#################################################################################

use strict;							# Strict variable enforcement

use Ethereal::Database;						# Database handler
use Ethereal::Words;						# Word segregation and handling


#################################################################################
# Data Members
#################################################################################
my $database;							# Database handle

my $res;							# Result handle
my $statement;							# Query

my $wrd;							# Word module
my $site;							# Site schema


#################################################################################
# Program Area
#################################################################################

	# Make sure schema is specified
	if ($site = shift(@ARGV))
	{
		# Initial handles
		$database = new Ethereal::Database();

		# Connect and Fetch
		$database->Connect();

	
		# Set search paths
		$database->Write("SET SEARCH_PATH TO $site,public");
	

		# Create instance
		$wrd = new Ethereal::Words();

		# Contacts
		$database->Pull(\$statement, "SELECT 
			  GalleryID       AS \"GalleryID\",
			  WorkID          AS \"WorkID\", 
			  WorkName        AS \"WorkName\",
			  WorkText        AS \"WorkText\",
			  WorkDescription AS \"WorkDescription\" 
			FROM Work
			WHERE WorkID NOT IN (0,1,2)
			ORDER BY GalleryID, WorkID");

		# Display
		print "Generating indexes:\n\n";
		
		# Loop and publish
		# Continue as long as there are works
		while ($res = $statement->fetchrow_hashref())
		{
			# Evaluate
			# Check for faults
			eval
			{
				# Calculate and weight
				$wrd->Reverse($database, 
					$res->{'GalleryID'},
					$res->{'WorkID'},
					$res->{'WorkName'},
					$res->{'WorkDescription'},
					$res->{'WorkText'}
				 );

				 # Commit to database
				 $database->Commit();

				 # Display notice
				 print " $res->{GalleryID}/$res->{WorkID} .. DONE!\n";
			};

			if ($@)
			{
				# Rollback transaction
				$database->Rollback();

				 # Display notice
				 print " $res->{GalleryID}/$res->{WorkID} .. FAILED!\n";
			}
		}
	
		# End
		$statement->finish();

		# Notice
		print "ALL DONE!\n\n";
	}

	# Otherwise warn
	else
	{
		# Simple useage instead of error
		print "Ethereal Realms reverse index generation command-line interface:\n";
		print "Usage: ./reverse.pl {schema}\n\n";
	}
